@@ -1,7 +1,7 @@
 
 # The R Commander and command logger
 
-# last modified 2013-11-09 by John Fox
+# last modified 2013-12-04 by John Fox
 
 # contributions by Milan Bouchet-Valat, Richard Heiberger, Duncan Murdoch, Erich Neuwirth, Brian Ripley
 
@@ -69,6 +69,14 @@ Commander <- function(){
     tkimage.create("photo", "::image::dataIcon", file = system.file("etc", "data.gif", package="Rcmdr"))
     tkimage.create("photo", "::image::modelIcon", file = system.file("etc", "model.gif", package="Rcmdr"))
     tkimage.create("photo", "::image::removeIcon", file = system.file("etc", "remove.gif", package="Rcmdr"))
+    tkimage.create("photo", "::image::copyIcon", file = system.file("etc", "copy.gif", package="Rcmdr"))
+    tkimage.create("photo", "::image::cutIcon", file = system.file("etc", "cut.gif", package="Rcmdr"))
+    tkimage.create("photo", "::image::deleteIcon", file = system.file("etc", "delete.gif", package="Rcmdr"))
+    tkimage.create("photo", "::image::findIcon", file = system.file("etc", "find.gif", package="Rcmdr"))
+    tkimage.create("photo", "::image::pasteIcon", file = system.file("etc", "paste.gif", package="Rcmdr"))
+    tkimage.create("photo", "::image::redoIcon", file = system.file("etc", "redo.gif", package="Rcmdr"))
+    tkimage.create("photo", "::image::undoIcon", file = system.file("etc", "undo.gif", package="Rcmdr"))
+    
     # locate Rcmdr etc directory and directory for menus (usually the same)
     etc <- setOption("etc", system.file("etc", package="Rcmdr"))
     etcMenus <- setOption("etcMenus", etc)
@@ -206,7 +214,9 @@ Commander <- function(){
     putRcmdr("restoreTab", FALSE)
     putRcmdr("cancelDialogReopen", FALSE)
     putRcmdr("last.search", "")
+#   putRcmdr("editor.accessed", FALSE)
     # set up Rcmdr default and text (log) fonts, Tk scaling factor
+#   if (!WindowsP()) tk2theme("clearlooks")
     default.font.size.val <- abs(as.numeric(.Tcl("font actual TkDefaultFont -size")))
     if (is.na(default.font.size.val)) default.font.size.val <- 10
     default.font.size <- as.character(setOption("default.font.size", default.font.size.val))
@@ -262,6 +272,8 @@ Commander <- function(){
     setOption("log.commands", TRUE)
     setOption("use.knitr", FALSE)
     setOption("use.markdown", !getRcmdr("use.knitr"))
+    if ((!packageAvailable("markdown")) || (!packageAvailable("knitr"))) putRcmdr("use.markdown", FALSE)
+    if (!packageAvailable("knitr")) putRcmdr("use.knitr", FALSE)
     putRcmdr("startNewCommandBlock", TRUE)
     putRcmdr("startNewKnitrCommandBlock", TRUE)
     putRcmdr("rmd.generated", FALSE)
@@ -815,12 +827,12 @@ Commander <- function(){
     if (getRcmdr("use.knitr")) tkadd(notebook, RnwFrame, text=gettextRcmdr("knitr Document"), padding=6)
     tkgrid(notebook, sticky="news")
     if (.log.commands && .console.output) tkgrid(submitButton, sticky="w", pady=c(0, 6))
-    tkgrid(labelRcmdr(outputFrame, text=gettextRcmdr("Output"), foreground="black"),
+    tkgrid(labelRcmdr(outputFrame, text=gettextRcmdr("Output"), foreground=getRcmdr("title.color"), font="RcmdrTitleFont"),
         if (.log.commands && !.console.output) submitButton, sticky="sw", pady=c(6, 6))
     tkgrid(.output, outputYscroll, sticky="news", columnspan=2)
     tkgrid(outputXscroll, columnspan=1 + (.log.commands && !.console.output))
     if (!.console.output) tkgrid(outputFrame, sticky="news", padx=10, pady=0, columnspan=2)
-    tkgrid(labelRcmdr(messagesFrame, text=gettextRcmdr("Messages"), foreground="black"), sticky="w", pady=c(6, 6))
+    tkgrid(labelRcmdr(messagesFrame, text=gettextRcmdr("Messages"), foreground=getRcmdr("title.color"), font="RcmdrTitleFont"), sticky="w", pady=c(6, 6))
     tkgrid(.messages, messagesYscroll, sticky="news", columnspan=2)
     tkgrid(messagesXscroll)
     if (!.console.output) tkgrid(messagesFrame, sticky="news", padx=10, pady=0, columnspan=2) ##rmh & J. Fox
@@ -902,6 +914,34 @@ Commander <- function(){
     tkbind(.rmd, "<Control-E>", editMarkdown)
     tkbind(.rnw, "<Control-e>", editKnitr)
     tkbind(.rnw, "<Control-E>", editKnitr)
+    if (MacOSXP()){
+        tkbind(.commander, "<Meta-x>", onCut)
+        tkbind(.commander, "<Meta-X>", onCut)
+        tkbind(.commander, "<Meta-c>", onCopy)
+        tkbind(.commander, "<Meta-C>", onCopy)
+        tkbind(.commander, "<Meta-v>", onPaste)
+        tkbind(.commander, "<Meta-V>", onPaste)
+        tkbind(.commander, "<Meta-r>", onSubmit)
+        tkbind(.commander, "<Meta-R>", onSubmit)
+        tkbind(.commander, "<Meta-Tab>", onSubmit)
+        tkbind(.commander, "<Meta-f>", onFind)
+        tkbind(.commander, "<Meta-F>", onFind)
+        tkbind(.commander, "<Meta-s>", saveLog)
+        tkbind(.commander, "<Meta-S>", saveLog)
+        tkbind(.commander, "<Meta-a>", onSelectAll)
+        tkbind(.commander, "<Meta-A>", onSelectAll)
+        tkbind(.commander, "<Meta-w>", onRedo)
+        tkbind(.commander, "<Meta-W>", onRedo)
+        tkbind(.log, "<Meta-ButtonPress-1>", contextMenuLog)
+        tkbind(.rmd, "<Meta-ButtonPress-1>", contextMenuRmd)
+        tkbind(.rnw, "<Meta-ButtonPress-1>", contextMenuRnw)
+        tkbind(.output, "<Meta-ButtonPress-1>", contextMenuOutput)
+        tkbind(.messages, "<Meta-ButtonPress-1>", contextMenuMessages)
+        tkbind(.rmd, "<Meta-e>", editMarkdown)
+        tkbind(.rmd, "<Meta-E>", editMarkdown)
+        tkbind(.rnw, "<Meta-e>", editKnitr)
+        tkbind(.rnw, "<Meta-E>", editKnitr)
+    }
     tkwm.deiconify(.commander)
     tkfocus(.commander)
     if (getRcmdr("crisp.dialogs")) tclServiceMode(on=TRUE)
